﻿using System;
using System.Diagnostics;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;
using System.Collections.Generic;
using Newtonsoft.Json.Linq;
using System.Net;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;


class groups
{
    //replace api_key placeholder with your own value
    private static String api_Url = "https://sandbox.e-signlive.com/api/packages";
    private static String api_Key = "api_key";

    public static void Main(string[] args)
    {
        EslClient eslClient = new EslClient(api_Key, api_Url);

        /*----------------------------------------Creating Groups---------------------------------------*/

        Group emptyGroup = GroupBuilder.NewGroup(".NET developers")
            .WithId(new GroupId("group2"))
            .WithEmail("esl.signer@example.com")
            .WithoutIndividualMemberEmailing()
            .Build();

        Group createdEmptyGroup = eslClient.GroupService.CreateGroup(emptyGroup);

        eslClient.GroupService.InviteMember(createdEmptyGroup.Id, GroupMemberBuilder.NewGroupMember("esl.signer1@example.com")
            .AsMemberType(GroupMemberType.MANAGER)
            .Build());

        eslClient.GroupService.InviteMember(createdEmptyGroup.Id, GroupMemberBuilder.NewGroupMember("esl.signer2@example.com")
            .AsMemberType(GroupMemberType.REGULAR)
            .Build());

        /*-------------------------------------Retrieve Groups--------------------------------------*/

        List<Group> allGroups = eslClient.GroupService.GetMyGroups();
        foreach (Group group in allGroups)
        {
            Debug.WriteLine(group.Name + " with email " + group.Email + " and id " + group.Id.Id);
            List<GroupMember> allMembers = eslClient.GroupService.GetGroupMembers(group.Id);
            foreach (GroupMember member in allMembers)
            {
                Debug.WriteLine(member.GroupMemberType.ToString() + " " + member.FirstName + " " + member.LastName + " with email " + member.Email);
            }
        }

        /*------------------------------------------Apply Group Signature----------------------------------------*/

        Group myGroup = allGroups[0];

        DocumentPackage superDuperPackage = PackageBuilder.NewPackageNamed("My Package with Group Signers .NET Developers")
            .WithSigner(SignerBuilder.NewSignerFromGroup(myGroup.Id)
                .CanChangeSigner()
                .DeliverSignedDocumentsByEmail())
            .WithDocument(DocumentBuilder.NewDocumentNamed("My Document")
                .FromFile("DOC_FILE_PATH")
                .WithSignature(SignatureBuilder.SignatureFor(myGroup.Id)
                  .OnPage(0)
                  .AtPosition(370, 680)))
            .Build();

        PackageId packageId = eslClient.CreateAndSendPackage(superDuperPackage);

    }
}